summaryrefslogtreecommitdiff
path: root/include/m_protocols.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/m_protocols.h')
-rw-r--r--include/m_protocols.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/include/m_protocols.h b/include/m_protocols.h
index fc21f8d9a4..a437e5aa5f 100644
--- a/include/m_protocols.h
+++ b/include/m_protocols.h
@@ -217,12 +217,16 @@ typedef struct {
#define MS_PROTO_ENUMPROTOS "Proto/EnumProtos"
// determines if a protocol module is loaded or not
-// wParam = 0
+// wParam = 0 (unused)
// lParam = (LPARAM)(const char*)szName
// Returns a pointer to the PROTOACCOUNT if the protocol is loaded, or
// NULL if it isn't.
#define MS_PROTO_ISPROTOCOLLOADED "Proto/IsProtocolLoaded"
+__forceinline PROTOCOLDESCRIPTOR* IsProtocolLoaded(const char *szProto)
+{ return (PROTOCOLDESCRIPTOR*)CallService(MS_PROTO_ISPROTOCOLLOADED, 0, (LPARAM)szProto);
+}
+
// gets the network-level protocol associated with a contact
// wParam = (MCONTACT)hContact
// lParam = 0
@@ -217,12 +217,16 @@ typedef struct {
// lParam = (LPARAM)(const char*)szName
-// Returns a pointer to the PROTOACCOUNT if the protocol is loaded, or
+// Returns a pointer to the PROTOCOLDESCRIPTOR if the protocol is loaded, or
// NULL if it isn't.
#define MS_PROTO_ISPROTOCOLLOADED "Proto/IsProtocolLoaded"